( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionfile_id_diz.so )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionfile_id_diz.so.1.0.0 libgwplugindescriptionfile_id_diz.so )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionmp3.so.1 )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionmp3.so.1.0.0 libgwplugindescriptionmp3.so.1 )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionhtml.so )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionhtml.so.1.0.0 libgwplugindescriptionhtml.so )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptiondescript_ion.so.1 )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptiondescript_ion.so.1.0.0 libgwplugindescriptiondescript_ion.so.1 )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionmpc.so.1 )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionmpc.so.1.0.0 libgwplugindescriptionmpc.so.1 )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionmp3.so )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionmp3.so.1.0.0 libgwplugindescriptionmp3.so )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionmpc.so )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionmpc.so.1.0.0 libgwplugindescriptionmpc.so )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionfile_id_diz.so.1 )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionfile_id_diz.so.1.0.0 libgwplugindescriptionfile_id_diz.so.1 )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptiondescript_ion.so )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptiondescript_ion.so.1.0.0 libgwplugindescriptiondescript_ion.so )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionavi.so )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionavi.so.1.0.0 libgwplugindescriptionavi.so )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionhtml.so.1 )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionhtml.so.1.0.0 libgwplugindescriptionhtml.so.1 )
( cd usr/share/gwhere/plugins/descr ; rm -rf libgwplugindescriptionavi.so.1 )
( cd usr/share/gwhere/plugins/descr ; ln -sf libgwplugindescriptionavi.so.1.0.0 libgwplugindescriptionavi.so.1 )
( cd usr/share/gwhere/plugins/catalog ; rm -rf libgwplugincataloggwcatalog.so )
( cd usr/share/gwhere/plugins/catalog ; ln -sf libgwplugincataloggwcatalog.so.1.0.0 libgwplugincataloggwcatalog.so )
( cd usr/share/gwhere/plugins/catalog ; rm -rf libgwplugincatalogcsv.so )
( cd usr/share/gwhere/plugins/catalog ; ln -sf libgwplugincatalogcsv.so.1.0.0 libgwplugincatalogcsv.so )
( cd usr/share/gwhere/plugins/catalog ; rm -rf libgwplugincatalogcsv.so.1 )
( cd usr/share/gwhere/plugins/catalog ; ln -sf libgwplugincatalogcsv.so.1.0.0 libgwplugincatalogcsv.so.1 )
( cd usr/share/gwhere/plugins/catalog ; rm -rf libgwplugincataloggwcatalog.so.1 )
( cd usr/share/gwhere/plugins/catalog ; ln -sf libgwplugincataloggwcatalog.so.1.0.0 libgwplugincataloggwcatalog.so.1 )
